"""
Collect all public opentmi API's
"""
from opentmi_client.api.client import create, OpenTmiClient
from opentmi_client.api.build import Build, Vcs, Ci, Target, Hardware
from opentmi_client.api.result import Result
from opentmi_client.api.result import Job
from opentmi_client.api.result import Environment
from opentmi_client.api.result import Sut
from opentmi_client.api.result import Dut
from opentmi_client.api.result import Execution
from opentmi_client.api.result import Framework
from opentmi_client.api.result import File
from opentmi_client.api.result import Provider
from opentmi_client.api.event import Event
from opentmi_client.api.testcase import Testcase

Client = OpenTmiClient
